@@ -41,6 +41,11 @@ class HDRVAL:
         self.raw_response_400 = responses.raw_resp_400
         self.response_favicon = responses.resp_favicon
         self.long_response = responses.long_resp
+        self.http_resp = responses.http_resp
+        self.https_resp = responses.https_resp
+        self.http_invalid_method = responses.http_invalid_method
+        self.http_invalid_protocol = responses.http_invalid_protocol
+        self.http_invalid_version = responses.http_invalid_version
 
         self.definitions = self.helpers.load_definitions("hdrval.json")
 
@@ -62,13 +67,23 @@ class HDRVAL:
         headers_200 = self._get_response_headers(self.response_hp)
         headers_400 = self._get_response_headers(self.raw_response_400) if self.raw_response_400 else {}
         headers_favicon = self._get_response_headers(self.response_favicon)
-        headers_long= self._get_response_headers(self.long_response)
+        headers_long = self._get_response_headers(self.long_response)
+        headers_http = self._get_response_headers(self.http_resp)if self.http_resp is not None else {}
+        headers_https = self._get_response_headers(self.https_resp)if self.https_resp is not None else {}
+        headers_http_IM = self._get_response_headers(self.http_invalid_method)if self.http_invalid_method is not None else {}
+        headers_http_IP = self._get_response_headers(self.http_invalid_protocol)if self.http_invalid_protocol is not None else {}
+        headers_http_IV = self._get_response_headers(self.http_invalid_version)if self.http_invalid_version is not None else {}
 
         combined_headers = self._combine_headers({
             '200': headers_200,
             '400': headers_400,
             'favicon': headers_favicon,
-            'long': headers_long
+            'long': headers_long,
+            'HTTP': headers_http,
+            'HTTPS': headers_https,
+            'invalid_method': headers_http_IM,
+            'invalid_protocol': headers_http_IP,
+            'invalid_version': headers_http_IV,
         })
 
         if not combined_headers:
@@ -118,9 +133,7 @@ class HDRVAL:
 
     def _get_response_headers(self, response) -> Dict[str, str]:
         """
-        Extract and normalize headers from an HTTP response object.
-
-        Supports multiple response formats (e.g., with .headers, .msg, or .getheaders).
+        Extract and normalize headers from an HTTP response object
 
         Args:
             response: HTTP response object.
@@ -128,29 +141,12 @@ class HDRVAL:
         Returns:
             Dictionary of headers with lowercase keys.
         """
-        if not response:
-            return {}
-
         headers = {}
-
-        if hasattr(response, 'headers'):
-            if hasattr(response.headers, 'items'):
-                headers = {k.lower(): v for k, v in response.headers.items()}
-            else:
-                for header_name, header_value in response.headers:
-                    headers[header_name.lower()] = header_value
-        elif hasattr(response, 'msg') and hasattr(response.msg, 'items'):
-            headers = {k.lower(): v for k, v in response.msg.items()}
-        elif hasattr(response, 'getheaders'):
-            for header_name, header_value in response.getheaders():
-                headers[header_name.lower()] = header_value
-
-        if hasattr(response, 'msg') and hasattr(response.msg, 'keys'):
-            for key in response.msg.keys():
-                if key.lower() not in headers:
-                    headers[key.lower()] = response.msg[key]
-
-        return headers
+        
+        if response is not None and hasattr(response, 'headers'):
+            headers = {k.lower(): v for k, v in dict(response.headers).items()}
+        
+            return headers
 
     def _combine_headers(self, source_headers: Dict[str, Dict[str, str]]) -> Dict[str, Dict[str, Any]]:
         """
@@ -303,6 +299,8 @@ class HDRVAL:
             technologies.extend(self._parse_aspnet_version_header(header_value))
         elif header_name.lower() == "x-aspnetmvc-version":
             technologies.extend(self._parse_aspnetmvc_version_header(header_value))
+        elif header_name.lower() == "x-azure-ref":
+            technologies.append({'name': 'x-azure-ref', 'version': None})
         else:
             technologies.extend(self._parse_generic_header(header_value))
 
@@ -317,6 +315,7 @@ class HDRVAL:
         - "nginx/1.18.0"
         - "nginx"
         - "Microsoft-IIS/10.0"
+        - "Google Frontend"
 
         Args:
             header_value: Server header value.
@@ -325,6 +324,21 @@ class HDRVAL:
             List of technology dictionaries.
         """
         technologies = []
+        
+        # Check for known compound names that shouldn't be split
+        compound_servers = ["Google Frontend", "Microsoft-HTTPAPI", "Apache Tomcat"]
+        for compound in compound_servers:
+            if compound.lower() in header_value.lower():
+                # Extract version if present
+                pattern = f"{re.escape(compound)}(?:/([\\w\\.-]+))?"
+                match = re.search(pattern, header_value, re.IGNORECASE)
+                if match:
+                    version = match.group(1) if match.group(1) else None
+                    technologies.append({'name': compound, 'version': version})
+                    # Remove this compound from further processing
+                    header_value = re.sub(pattern, '', header_value, flags=re.IGNORECASE).strip()
+        
+        # Now process the remaining parts normally
         parts = header_value.split()
 
         for part in parts:
@@ -345,7 +359,7 @@ class HDRVAL:
                             version = version_match.group(2)
                             technologies.append({'name': name, 'version': version})
                         else:
-                            if re.match(r'^[A-Za-z][A-Za-z0-9\-_]*$', main_part):
+                            if re.match(r'^[A-Za-z][A-Za-z0-9\-_]*', main_part):
                                 technologies.append({'name': main_part, 'version': None})
 
                     # Then add the OS
@@ -359,7 +373,7 @@ class HDRVAL:
                     technologies.append({'name': name, 'version': version})
                 else:
                     # Just the technology name without version (e.g., "nginx")
-                    if re.match(r'^[A-Za-z][A-Za-z0-9\-_]*$', part):
+                    if re.match(r'^[A-Za-z][A-Za-z0-9\-_]*', part):
                         technologies.append({'name': part, 'version': None})
         return technologies
 
@@ -410,7 +424,7 @@ class HDRVAL:
                     technologies.append({'name': name, 'version': version})
                 else:
                     # Just the technology name (e.g., "ASP.NET", "Express", "IS VUT")
-                    if re.match(r'^[A-Za-z][A-Za-z0-9\-_\s\.]*$', part):
+                    if re.match(r'^[A-Za-z][A-Za-z0-9\-_\s]*$', part):
                         technologies.append({'name': part, 'version': None})
 
         return technologies
@@ -532,7 +546,7 @@ class HDRVAL:
             if isinstance(definition, dict) and 'content' in definition:
                 if definition['content'].lower() == tech_name:
                     return {
-                        'category': definition.get('category', 'unknown'),
+                        'category': definition.get('category', 'Unknown'),
                         'technology': definition.get('technology', technology['name']),
                         'name': technology['name'],
                         'version': technology['version'],
@@ -541,86 +555,64 @@ class HDRVAL:
 
         return None
 
-    def _add_software_node(self, tech: Dict[str, Any], is_classified: bool) -> None:
+    def _store_technology(self, tech: Dict[str, Any], is_classified: bool) -> None:
         """
-         Add a software node to the ptjsonlib model with specific source information.
-
-        Creates descriptions showing exact header values and sources where each
-        technology was found (e.g., "Server: Apache [200 HP, 200 FAVICON]").
-
+        Store detected technology in the storage system.
+        
         Args:
-            tech: Parsed or classified technology with tech_sources and tech_values.
-            is_classified: Whether the technology was matched against known definitions.
+            tech: Parsed or classified technology data
+            is_classified: Whether the technology was matched against known definitions
         """
-        node_key = str(uuid.uuid4())
-
-        category_mapping = {
-            'prgLanguage': 'swPrgLanguage',
-            'webServer': 'swWebServer',
-            'webServerModule': 'swWebServerModule',
-            'framework': 'swFramework',
-            'cms': 'swCms',
-            'operatingSystem': 'swOperatingSystem'
-        }
-
-        sw_type = None
-        if is_classified and tech.get('category') != 'unknown':
-            sw_type = category_mapping.get(tech['category'])
-
-        version = tech.get('version') if tech.get('version') else None
+        
+        if is_classified and tech.get('category') != 'Unknown':
+            tech_type = tech['category']
+        else:
+            tech_type = None
+        
+        tech_name = tech.get('technology', tech['name'])
+        version = tech.get('version')
+        
         header_name = tech.get('header', 'Unknown')
-
         tech_values = tech.get('tech_values', {})
         tech_sources = tech.get('tech_sources', [])
-
-
+        
         if tech_values and tech_sources:
-            # Use the first source's value
             first_source = tech_sources[0]
-            extracted_value = tech_values.get(first_source, tech['name'])
+            extracted_value = tech_values.get(first_source, tech_name)
             source_descriptions = [self._get_source_description(source) for source in tech_sources]
             sources_text = ', '.join(source_descriptions)
             description = f"{header_name}: {extracted_value} [{sources_text}]"
         else:
-            # Fallback
-            if is_classified:
-                description = tech.get('description', f"{header_name}: {tech['name']}")
-            else:
-                full_header = tech.get('full_header', tech['name'])
-                description = f"{header_name}: {full_header}"
-
-        if is_classified:
-            name = tech.get('technology', tech['name'])
-        else:
-            name = tech['name']
-
-        properties = {}
-
-        if sw_type:
-            properties["type"] = sw_type
-        properties["name"] = name
-        if version:
-            properties["version"] = version
-        properties["description"] = description
-
-        node = {
-            "type": "sw",
-            "key": node_key,
-            "parent": None,
-            "parentType": None,
-            "properties": properties,
-            "vulnerabilities": []
-        }
-
-        self.ptjsonlib.add_node(node)
+            description = f"{header_name}: {tech_name}"
+        
+        storage.add_to_storage(
+            technology=tech_name,
+            version=version,
+            technology_type=tech_type,
+            vulnerability="PTV-WEB-INFO-SRVHDR",
+            description=description
+        )
 
     def _get_source_description(self, source: str) -> str:
         """Map source names to their descriptive labels with status codes."""
+        
+        sc_http = getattr(self.http_resp, 'status_code', 0)
+        sc_https = getattr(self.https_resp, 'status_code', 0)
+        sc_im = getattr(self.http_invalid_method, 'status_code', 0)
+        sc_ip = getattr(self.http_invalid_protocol, 'status_code', 0)
+        sc_iv = getattr(self.http_invalid_version, 'status_code', 0)
+
         source_map = {
             '200': '200 HP',
             '400': '400 %', 
             'favicon': '200 FAVICON',
-            'long': '400 LONGURL'
+            'long': '400 LONGURL',
+            'HTTP': f"{sc_http} HTTP",
+            'HTTPS': f"{sc_https} HTTPS",
+            'invalid_method': f"{sc_http} invalid method",
+            'invalid_protocol': f"{sc_http} invalid protocol",
+            'invalid_version': f"{sc_http} invalid version"
+
         }
         return source_map.get(source, source.upper())
 
@@ -681,31 +673,20 @@ class HDRVAL:
                 for tech, is_classified in technologies_by_header[header_name]:
                     category_text = ""
                     if is_classified and 'category' in tech:
-                        category_map = {
-                            'prgLanguage': 'Programming language',
-                            'webServer': 'Web server',
-                            'webServerModule': 'Web server module',
-                            'framework': 'Framework',
-                            'cms': 'CMS',
-                            'operatingSystem': 'Operating system'
-                        }
-                        category_text = f" ({category_map.get(tech['category'], tech['category'])})"
+                        category_text = f" ({tech['category']})"
                     elif not is_classified:
-                        category_text = " (unknown)"
+                        category_text = " (Unknown)"
 
                     version_text = f" {tech['version']}" if tech.get('version') else ""
                     tech_name = tech.get('technology', tech['name'])
 
                     ptprint(f"{tech_name}{version_text}{category_text}", "VULN", not self.args.json, indent=8)
 
-        if found_technologies or unclassified_technologies:
-            self.ptjsonlib.add_vulnerability("PTV-WEB-INFO-OSSEN")
-
         for tech, is_classified in [
             *( (t, True) for t in found_technologies ),
             *( (t, False) for t in unclassified_technologies )
         ]:
-            self._add_software_node(tech, is_classified)
+            self._store_technology(tech, is_classified)
 
 
 def run(args: object, ptjsonlib: object, helpers: object, http_client: object, responses: StoredResponses):
