@@ -58,7 +58,7 @@ class OSCS:
         ptprint(__TESTLABEL__, "TITLE", not self.args.json, colortext=True)
         resource = self._find_static_resource()
         if not resource:
-            ptprint("No static source found for test", "ERROR", not self.args.json, indent=4)
+            ptprint("No static source found for test", "INFO", not self.args.json, indent=4)
             return
 
         resource_url, lower_resp, ct_lower = resource
@@ -88,21 +88,27 @@ class OSCS:
         favicon = base + '/favicon.ico'
         resp, ct = self._fetch(favicon)
 
-        if resp.status_code in (301, 302):
-            ptprint(f"Error: Redirect detected to {resp.headers.get('Location')}", "ERROR", not self.args.json, indent=4)
-            return None
-        elif resp.status_code == 200:
-            return favicon, resp, ct
+        if resp is not None:
+            if resp.status_code in (301, 302):
+                ptprint(f"Redirect detected to {resp.headers.get('Location')}", "INFO", not self.args.json, indent=4)
+                return None
+            elif resp.status_code == 200:
+                return favicon, resp, ct
 
         resp_home, _ = self._fetch(base + '/')
 
-        if resp_home.status_code in (301, 302):
-            ptprint(f"Error: Redirect to {resp_home.headers.get('Location')}","ERROR", not self.args.json, indent=4)
-            return None
-        elif resp_home.status_code != 200:
-            ptprint(f"Error: Homepage returned {resp_home.status_code}","ERROR", not self.args.json, indent=4)
+        if resp_home is not None:
+            if resp_home.status_code in (301, 302):
+                ptprint(f"Redirect to ghhgj {resp_home.headers.get('Location')}","INFO", not self.args.json, indent=4)
+                return None
+            elif resp_home.status_code != 200:
+                ptprint(f"Homepage returned {resp_home.status_code}","INFO", not self.args.json, indent=4)
+                return None
+        else:
+            ptprint("Connection error occurred", "INFO", not self.args.json, indent=4)
             return None
 
+
         html = resp_home.text or ''
         for match in re.finditer(
             r'(?:href|src)=["\']([^"\']+\.(?:js|css|png|jpg|jpeg|gif|ico))["\']',
@@ -114,8 +120,9 @@ class OSCS:
                 continue
 
             r, ct = self._fetch(candidate_url)
-            if r.status_code == 200:
-                return candidate_url, r, ct
+            if r is not None:
+                if r.status_code == 200:
+                    return candidate_url, r, ct
         return None
 
     def _fetch(self, url: str) -> tuple:
@@ -129,7 +136,12 @@ class OSCS:
             tuple: (response object, content type string).
         """
         resp = self.helpers.fetch(url)
-        return resp, resp.headers.get('Content-Type', '')
+        
+        if resp is not None:
+            return resp, resp.headers.get('Content-Type', '')
+        else:
+            return None, ''
+
 
     def _make_alt_case_url(self, resource_url: str) -> str:
         """
@@ -167,14 +179,15 @@ class OSCS:
 
         This method also records the vulnerability code and OS property in the JSON.
         """
-        self.ptjsonlib.add_vulnerability("PTV-WEB-INFO-OSSEN")
-
-        if r1.status_code == r2.status_code and ct1 == ct2:
-            self.ptjsonlib.add_properties({"os": "osWindows"})
-            ptprint("Identified OS: Windows", "VULN", not self.args.json, indent = 4)
+        if r1 is not None and r2 is not None:
+            if r1.status_code == r2.status_code and ct1 == ct2:
+                storage.add_to_storage(technology="Windows", technology_type="Os", vulnerability="PTV-WEB-INFO-OSSEN")
+                ptprint("Identified OS: Windows", "VULN", not self.args.json, indent = 4)
+            else:
+                storage.add_to_storage(technology="Linux", technology_type="Os", vulnerability="PTV-WEB-INFO-OSSEN")
+                ptprint("Identified OS: Unix / Linux", "VULN", not self.args.json, indent = 4)
         else:
-            self.ptjsonlib.add_properties({"os": "osUnix"})
-            ptprint("Identified OS: Unix / Linux", "VULN", not self.args.json, indent = 4)
+            ptprint("Connection error occurred", "INFO", not self.args.json, indent=4)
 
 
 def run(args: object, ptjsonlib: object, helpers: object, http_client: object, responses: StoredResponses):
