@@ -107,6 +107,8 @@ class PLLNG:
                     for ext_entry in self.extensions:
                         ext = ext_entry["extension"]
                         if abs_url.lower().endswith(f".{ext}"):
+                            if self.args.verbose:
+                                ptprint(f"Match: {abs_url}", "ADDITIONS", not self.args.json, indent=4, colortext=True)
                             return ext_entry
         return None
 
@@ -126,8 +128,11 @@ class PLLNG:
                 ext = ext_entry["extension"]
                 test_url = f"{base_url}/{name}.{ext}"
                 resp = self.helpers.fetch(test_url, allow_redirects=True)
-                if resp.status_code == 200:
-                    return ext_entry
+                if resp is not None:
+                    if resp.status_code == 200:
+                        if self.args.verbose:
+                            ptprint(f"Match: {test_url}", "ADDITIONS", not self.args.json, indent=4, colortext=True)
+                        return ext_entry
         return None
 
     def _report(self, result):
@@ -140,8 +145,7 @@ class PLLNG:
         if result:
             language = result["technology"]
             ext = result["extension"].capitalize()
-            self.ptjsonlib.add_vulnerability("PTV-WEB-INFO-LNGEX")
-            self.ptjsonlib.add_properties({"webProgrammingLanguage": f"webProgrammingLanguage{ext}"})
+            storage.add_to_storage(technology=language, technology_type="Interpret", vulnerability="PTV-WEB-INFO-LNGEX")
             ptprint(f"Identified language: {language}", "VULN", not self.args.json, indent=4)
         else:
             ptprint(f"It was not possible to identify the programming language", "INFO", not self.args.json, indent=4)
